Uses of Package
org.biojava.bio

Packages that use org.biojava.bio
Package
Description
The core classes that will be used throughout the bio packages.
Databases of generic structured data (annotation) objects.
Probability distributions over Alphabets.
HMM and Dynamic Programming Algorithms.
 
 
The classes and interfaces in this package cover common molecular biological techniques such as restriction digests and PCR.
Experimental parsers using the tagvalue framework.
GFF manipulation.
Support for reading and writing GFF3.
Tools for working with profile Hidden Markov Models from the HMMer package.
Support classes for Homologene data.
A flat-file ascii index of ascii flat files as per the OBDA specification.
Parser for Phred output
SSAHA sequence searching API.
 
Process files as streams of records, each with tags with values.
Objects for representing Unigene clusters.
Event-driven parsing system for the Extensible Feature Format (XFF).
Utilities to aid in performing various physical analysis of proteins.
Classes and interfaces to load Amino Acid Index database files.
Interfaces and classes for representing sequence similarity search results.
Classes and interfaces for defining biological sequences and informatics objects.
Collections of biological sequence data.
Client for the OBDA BioFetch protocol.
Support for OBDA flatfile databases.
Sequences and SequenceDBs which are composed from data taken from a number of data sources.
The classes and interfaces for defining sequence similarity and honology.
Standard in-memory implementations of Sequence and Feature.
Classes and interfaces for processing and producing flat-file representations of sequences.
Classes for converting between AGAVE XML and BioJava objects.
Tools for reading and writing an XML representation of BioJava's FeatureFilter language.
Code for projecting Feature objects and systematically altering their properties.
Representation of the Symbols that make up a sequence, and locations within them.
Taxonomy object for representing species information.
Open Bio Sequence Database Access (OBDA) registry support.
A general-purpose API for ontologies.
 
Mathematical utility classes.
This package is used to perform regular expression searches of SymbolLists defined in arbitrary Alphabets.
 
The Biojava extensions packages, classes that extend the core biojava functionality
Classes to represent biological entities and their relationships.
This package contains the interfaces that need to be implemented by discrete alignment services.
This package holds implementations of the org.biojava3.ws.alignment interfaces for the NCBI remote QBlast services through the WWW.
Interactions between biojavax objects and a DB.
Interfaces to NCBI data.
Rich implementations of Sequences, Locations and Features.
Classes to support the I/O of RichSequence and Bioentry objects.
Extensions to the biojava ontology model that represent BioSQL ontology.