Uses of Package
org.biojava.bio.search
Packages that use org.biojava.bio.search
Package
Description
Interfaces and classes for representing sequence similarity search results.
-
Classes in org.biojava.bio.search used by org.biojava.bio.searchClassDescriptionInterface for things that perform matches.A SearchContentHandler class that implements filtering in chains of SearchContentHandler instances.Applies test to the value specified by the key in hit properties.Applies test to the value specified by the key in search properties.Applies test to the value specified by the key in subhit properties.Class for implementing tests with BlastLikeSearchFilter objects.An adapter for SearchContentHandler.
SearchContentHandleris a notification interface for objects which listen to search stream parsers.Objects of this type represent one particular hit (sequence and associated information) from a sequence similarity search.ByScoreComparatorcomparesSeqSimilaritySearchHits by their score.BySubHitCountComparatorcomparesSeqSimilaritySearchHits by their number of sub-hits.Objects of this type represent one particular result of a sequence similarity search.Objects of this type represent one particular sub-hit (one concrete sequence stretch within a sequence and associated information) from a sequence similarity search hit.ByScoreComparatorcomparesSeqSimilaritySearchSubHits by their score.BySubjectStartComparatorcomparesSeqSimilaritySearchSubHits by their start position on the subject sequence.