Uses of Package
org.biojava.bio.seq

Packages that use org.biojava.bio.seq
Package
Description
Probability distributions over Alphabets.
HMM and Dynamic Programming Algorithms.
The classes and interfaces in this package cover common molecular biological techniques such as restriction digests and PCR.
GFF manipulation.
Support for reading and writing GFF3.
Parser for Phred output
Objects for representing Unigene clusters.
Event-driven parsing system for the Extensible Feature Format (XFF).
Utilities to aid in performing various physical analysis of proteins.
Interfaces and classes for representing sequence similarity search results.
Classes and interfaces for defining biological sequences and informatics objects.
Collections of biological sequence data.
Client for the OBDA BioFetch protocol.
Support for OBDA flatfile databases.
Sequences and SequenceDBs which are composed from data taken from a number of data sources.
 
The classes and interfaces for defining sequence similarity and honology.
Standard in-memory implementations of Sequence and Feature.
Classes and interfaces for processing and producing flat-file representations of sequences.
Classes for converting between AGAVE XML and BioJava objects.
Tools for reading and writing an XML representation of BioJava's FeatureFilter language.
Event-driven parsing system for the Gene Annotation Markup Elements (GAME).
Code for projecting Feature objects and systematically altering their properties.
Interactions between biojavax objects and a DB.
Rich implementations of Sequences, Locations and Features.
Classes to support the I/O of RichSequence and Bioentry objects.