Uses of Class
org.biojava.utils.AbstractChangeable

Packages that use AbstractChangeable
Package
Description
The core classes that will be used throughout the bio packages.
 
Probability distributions over Alphabets.
HMM and Dynamic Programming Algorithms.
Support for reading and writing GFF3.
Tools for working with profile Hidden Markov Models from the HMMer package.
Support classes for Homologene data.
Parser for Phred output
Interfaces and classes for representing sequence similarity search results.
Classes and interfaces for defining biological sequences and informatics objects.
Collections of biological sequence data.
Sequences and SequenceDBs which are composed from data taken from a number of data sources.
The classes and interfaces for defining sequence similarity and honology.
Standard in-memory implementations of Sequence and Feature.
Classes and interfaces for processing and producing flat-file representations of sequences.
Code for projecting Feature objects and systematically altering their properties.
Representation of the Symbols that make up a sequence, and locations within them.
Taxonomy object for representing species information.
A general-purpose API for ontologies.
The Biojava extensions packages, classes that extend the core biojava functionality
Classes to represent biological entities and their relationships.
Interactions between biojavax objects and a DB.
Interfaces to NCBI data.
Rich implementations of Sequences, Locations and Features.
Objects that model the NCBI taxonomy schema as described in the BioSQL schema.
GA functions
Default implementations and abstract classes.
Extensions to the biojava ontology model that represent BioSQL ontology.