Package org.biojava.utils


package org.biojava.utils

Miscellaneous utility classes used by other BioJava components.

  • Class
    Description
    Useful base-class for objects implementing Changeable
    Interface for object which monitor long-running activities.
    An unchecked exception representing an Assertion failure.
     
    This is a flag interface that defines the common add/remove listener methods for classes and interfaces that wish to indicate that they are sources of ChangeEvents.
    This is a ChangeListener that ignores everything.
    Event which encapsulates a change in any mutable BioJava object.
    This is a ChangeListener that is designed to adapt events of one type from one source to events of another type emitted by another source.
    A ChangeForwarder that systematically uses a given type and wraps the old event.
    Interface implemented by ChangeHubs, i.e.
    Interface for objects which listen to ChangeEvents.
    An implementation that always vetoes everything.
    A listener that remembers the ChangeEvent of the last change.
    A listener that writes information about the event stream to a PrintStream.
    A utility class to provide management for informing ChangeListeners of ChangeEvents.
    Class for all constants which are used to indicate change types.
    Exception which is thrown when a ChangeListener does not wish a change to take place.
    Utility methods for manipulating class objects and resources.
    Implementations of Commitable support atomic changes from one known state to another via commit/rollback semantics.
     
    Some usefull constants for working with binary files.
    Makes running external executables easier, optionally under a watched thread.
    FileAsList creates a writable List implementation backed by a random access file.
    implements Changeable support with a ChangeHub that stores ChangeListener by key.
    Really simple connection pool for JDBC databases.
    Returns a DataSource that implements connection pooling Uses Jakarta Commons DBCP and Pool packages.
     
     
    Maps one object to another.
    A list that represents a series of values.
     
     
     
    utility methods for implementing the equals() and hashCode() methods of Objects.
    Overlap one map onto another.
    Event which signals a bad line when parsing a record.
    Listener for a ParseErrorEvent.
    Source for a ParseErrorEvent.
    Exception thrown when an error occurs in document parsing.
    Exception which is thrown if a child process managed by ProcessTools exceeds a specified time limit.
    Deprecated.
    preferable to use org.biojava.utils.ExecRunner or the org.biojava.utils.process package.
     
    Utility methods for handling META-INF/services files
    SimpleThreadPool is a basic implementation of ThreadPool for use where we don't wish to introduce a dependency on a 3rd-party pool.
     
    Lightweight implementation of Map which uses little memory to store a small number of mappings, at the expense of scalability.
    Lightweight implementation of Set which uses little memory to store a small number of items, at the expense of scalability.
     
    ThreadPool specifies basic thread-pooling operations such that third-party implementations may be used without requiring changes to BioJava.
    Class that represents the tristate values possible in a logical operation: true, false and indeterminate.
    a sub-class of java.util.Properties that provides the same constructors, adds two convenient load methods to load the properties from files and, most importantly, adds getPropertyAsXXX() methods to get a property as an object of type XXX.
    This is a utility implementation of Changeable that doesn't fire any events or keep references to any listeners.